#ifndef ATHREAD_H
#define ATHREAD_H

#include <QThread>
#include <QString>

class aThread : public QThread
{
  Q_OBJECT

public:
    aThread(QObject *parent = 0);
    void run();

    QString x;
    QString y;
    QString z;

public slots:
    void updateCoords();
    void processCoords(QString &data);
    void readProximity();
    void update();

signals:
    void deviceOrientation(QString x, QString y, QString z);
    void proximityState(QString state);
};

#endif // ATHREAD_H

